@@ -5,8 +5,9 @@
  *  Copyright (C) 2012  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,9 +20,6 @@
  *
  */
 
-#ifndef __CLIENT_INTERACTIVE_H
-#define __CLIENT_INTERACTIVE_H
-
 #include <dbus/dbus.h>
 
 void show_interactive(DBusConnection *connection, GMainLoop *mainloop);
@@ -32,5 +30,3 @@ int monitor_switch(int argc, char *argv[], int c, DBusConnection *conn);
 int config_switch(int argc, char *argv[], int c, DBusConnection *conn);
 int service_switch(int argc, char *argv[], int c, DBusConnection *conn,
 						struct service_data *service);
-
-#endif
