@@ -32,6 +32,7 @@
 #include <connman/plugin.h>
 #include <connman/device.h>
 #include <connman/network.h>
+#include <connman/service.h>
 #include <connman/inet.h>
 #include <connman/dbus.h>
 
@@ -86,17 +87,20 @@ static char *get_ident(const char *path)
 	return pos + 1;
 }
 
-static void create_device(struct dundee_data *info)
+static int create_device(struct dundee_data *info)
 {
 	struct connman_device *device;
 	char *ident;
+	int err;
 
 	DBG("%s", info->path);
 
 	ident = g_strdup(get_ident(info->path));
-	device = connman_device_create(ident, CONNMAN_DEVICE_TYPE_BLUETOOTH);
-	if (device == NULL)
+	device = connman_device_create("dundee", CONNMAN_DEVICE_TYPE_BLUETOOTH);
+	if (device == NULL) {
+		err = -ENOMEM;
 		goto out;
+	}
 
 	DBG("device %p", device);
 
@@ -106,7 +110,8 @@ static void create_device(struct dundee_data *info)
 
 	connman_device_set_data(device, info);
 
-	if (connman_device_register(device) < 0) {
+	err = connman_device_register(device);
+	if (err < 0) {
 		connman_error("Failed to register DUN device");
 		connman_device_unref(device);
 		goto out;
@@ -116,6 +121,7 @@ static void create_device(struct dundee_data *info)
 
 out:
 	g_free(ident);
+	return err;
 }
 
 static void destroy_device(struct dundee_data *info)
@@ -150,17 +156,18 @@ static void device_destroy(gpointer data)
 	g_free(info);
 }
 
-static void create_network(struct dundee_data *info)
+static int create_network(struct dundee_data *info)
 {
 	struct connman_network *network;
 	const char *group;
+	int err;
 
 	DBG("%s", info->path);
 
 	network = connman_network_create(info->path,
 				CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN);
 	if (network == NULL)
-		return;
+		return -ENOMEM;
 
 	DBG("network %p", network);
 
@@ -174,22 +181,30 @@ static void create_network(struct dundee_data *info)
 	group = get_ident(info->path);
 	connman_network_set_group(network, group);
 
-	connman_network_set_available(network, TRUE);
-
-	if (connman_device_add_network(info->device, network) < 0) {
+	err = connman_device_add_network(info->device, network);
+	if (err < 0) {
 		connman_network_unref(network);
-		return;
+		return err;
 	}
 
 	info->network = network;
+
+	return 0;
 }
 
 static void set_connected(struct dundee_data *info)
 {
+	struct connman_service *service;
+
 	DBG("%s", info->path);
 
 	connman_inet_ifup(info->index);
 
+	service = connman_service_lookup_from_network(info->network);
+	if (service == NULL)
+		return;
+
+	connman_service_create_ip4config(service, info->index);
 	connman_network_set_index(info->network, info->index);
 	connman_network_set_ipv4_method(info->network,
 					CONNMAN_IPCONFIG_METHOD_FIXED);
@@ -490,7 +505,7 @@ out:
 	g_free(gateway);
 }
 
-static gboolean device_changed(DBusConnection *connection,
+static gboolean device_changed(DBusConnection *conn,
 				DBusMessage *message,
 				void *user_data)
 {
@@ -556,6 +571,7 @@ static gboolean device_changed(DBusConnection *connection,
 static void add_device(const char *path, DBusMessageIter *properties)
 {
 	struct dundee_data *info;
+	int err;
 
 	info = g_hash_table_lookup(dundee_devices, path);
 	if (info != NULL)
@@ -601,14 +617,26 @@ static void add_device(const char *path, DBusMessageIter *properties)
 
 	g_hash_table_insert(dundee_devices, g_strdup(path), info);
 
-	create_device(info);
-	create_network(info);
+	err = create_device(info);
+	if (err < 0)
+		goto out;
+
+	err = create_network(info);
+	if (err < 0) {
+		destroy_device(info);
+		goto out;
+	}
 
 	if (info->active == TRUE)
 		set_connected(info);
+
+	return;
+
+out:
+	g_hash_table_remove(dundee_devices, path);
 }
 
-static gboolean device_added(DBusConnection *connection, DBusMessage *message,
+static gboolean device_added(DBusConnection *conn, DBusMessage *message,
 				void *user_data)
 {
 	DBusMessageIter iter, properties;
@@ -640,14 +668,14 @@ static gboolean device_added(DBusConnection *connection, DBusMessage *message,
 	return TRUE;
 }
 
-static void remove_device(DBusConnection *connection, const char *path)
+static void remove_device(DBusConnection *conn, const char *path)
 {
 	DBG("path %s", path);
 
 	g_hash_table_remove(dundee_devices, path);
 }
 
-static gboolean device_removed(DBusConnection *connection, DBusMessage *message,
+static gboolean device_removed(DBusConnection *conn, DBusMessage *message,
 				void *user_data)
 {
 	const char *path;
@@ -660,7 +688,7 @@ static gboolean device_removed(DBusConnection *connection, DBusMessage *message,
 
 	dbus_message_get_args(message, NULL, DBUS_TYPE_OBJECT_PATH, &path,
 				DBUS_TYPE_INVALID);
-	remove_device(connection, path);
+	remove_device(conn, path);
 	return TRUE;
 }
 
@@ -755,9 +783,9 @@ static int manager_get_devices(void)
 	return -EINPROGRESS;
 }
 
-static void dundee_connect(DBusConnection *connection, void *user_data)
+static void dundee_connect(DBusConnection *conn, void *user_data)
 {
-	DBG("connection %p", connection);
+	DBG("connection %p", conn);
 
 	dundee_devices = g_hash_table_new_full(g_str_hash, g_str_equal,
 					g_free, device_destroy);
@@ -765,9 +793,9 @@ static void dundee_connect(DBusConnection *connection, void *user_data)
 	manager_get_devices();
 }
 
-static void dundee_disconnect(DBusConnection *connection, void *user_data)
+static void dundee_disconnect(DBusConnection *conn, void *user_data)
 {
-	DBG("connection %p", connection);
+	DBG("connection %p", conn);
 
 	g_hash_table_destroy(dundee_devices);
 	dundee_devices = NULL;
@@ -789,18 +817,18 @@ static int dundee_init(void)
 	watch = g_dbus_add_service_watch(connection, DUNDEE_SERVICE,
 			dundee_connect, dundee_disconnect, NULL, NULL);
 
-	added_watch = g_dbus_add_signal_watch(connection, NULL, NULL,
+	added_watch = g_dbus_add_signal_watch(connection, DUNDEE_SERVICE, NULL,
 						DUNDEE_MANAGER_INTERFACE,
 						DEVICE_ADDED, device_added,
 						NULL, NULL);
 
-	removed_watch = g_dbus_add_signal_watch(connection, NULL, NULL,
-						DUNDEE_MANAGER_INTERFACE,
+	removed_watch = g_dbus_add_signal_watch(connection, DUNDEE_SERVICE,
+						NULL, DUNDEE_MANAGER_INTERFACE,
 						DEVICE_REMOVED, device_removed,
 						NULL, NULL);
 
-	device_watch = g_dbus_add_signal_watch(connection, NULL, NULL,
-						DUNDEE_DEVICE_INTERFACE,
+	device_watch = g_dbus_add_signal_watch(connection, DUNDEE_SERVICE,
+						NULL, DUNDEE_DEVICE_INTERFACE,
 						PROPERTY_CHANGED,
 						device_changed,
 						NULL, NULL);
